import tkinter as tk
from tkinter import simpledialog
import cv2
import os
import csv
import numpy as np
import pyttsx3
import datetime
import time

def show_capturing_screen():
    window = tk.Toplevel(root)
    window.title("Capturing Images")
    label = tk.Label(window, text="Capturing Images")
    label.pack()

    return window

def capture_images():
    window = show_capturing_screen()

  
    name = simpledialog.askstring("Enter Name", "Enter the name of the person:")

 
    if not name:
        print("Please enter a name")
        window.destroy()
        return

  
    with open('names.txt', 'r') as file:
        names = file.readlines()
        next_number = len(names) if len(names) == 0 else int(names[-1].split(':')[1]) + 1

 
    cap = cv2.VideoCapture(0)
    classifier = cv2.CascadeClassifier(cv2.data.haarcascades + "haarcascade_frontalface_default.xml")

    dirName = "./images/" + str(next_number)
    os.makedirs(dirName, exist_ok=True)

    count = 200 
    counter = 0  
    while counter < count:
        _, image = cap.read()
        gray_image = cv2.cvtColor(image, cv2.COLOR_BGR2GRAY)
        faces_detected = classifier.detectMultiScale(gray_image, scaleFactor=1.1, minNeighbors=5)
        

        if len(faces_detected) == 0:
            continue

        for (x, y, w, h) in faces_detected:
            roi_gray = gray_image[y:y + h, x:x + w]
            cv2.rectangle(image, (x, y), (x + w, y + h), (0, 255, 0), 2)  # Draw bounding box
            cv2.imwrite(dirName + "/img_" + str(counter) + ".jpg", roi_gray)
            counter += 1
            
        cv2.imshow("Capturing Images", image)
        cv2.waitKey(1)
            
    cap.release()
    cv2.destroyAllWindows()


    with open('names.txt', 'a') as file:
        file.write(name + ':' + str(next_number) + '\n')

    window.destroy()
    
def train_recognizer():
    recognizer = cv2.face.LBPHFaceRecognizer_create()
    faceCascade = cv2.CascadeClassifier(cv2.data.haarcascades + "haarcascade_frontalface_default.xml")
    font = cv2.FONT_HERSHEY_SIMPLEX


    with open('names.txt', 'r') as file:
        names_identifiers = file.readlines()

    names = []
    identifiers = []

    for name_identifier in names_identifiers:
        name, identifier = name_identifier.strip().split(':')
        names.append(name)
        identifiers.append(identifier)

  
    faces = []
    labels = []
    for identifier in identifiers:
        folder_path = "./images/" + identifier
        if os.path.isdir(folder_path):
            label = int(identifier)
            for filename in os.listdir(folder_path):
                image_path = os.path.join(folder_path, filename)
                image = cv2.imread(image_path, cv2.IMREAD_GRAYSCALE)
                faces.append(image)
                labels.append(label)


    recognizer.train(faces, np.array(labels))
    recognizer.save('./trainer/trainer.yml')

def recognize_person():
    train_recognizer()
    recognizer = cv2.face.LBPHFaceRecognizer_create()
    recognizer.read('./trainer/trainer.yml')
    faceCascade = cv2.CascadeClassifier(cv2.data.haarcascades + "haarcascade_frontalface_default.xml")
    font = cv2.FONT_HERSHEY_SIMPLEX
    engine = pyttsx3.init()
    last_entry_time = {}
    cam = cv2.VideoCapture(0)
    cam.set(3, 640)
    cam.set(4, 480)

    while True:
        ret, img = cam.read()
        gray = cv2.cvtColor(img, cv2.COLOR_BGR2GRAY)
        faces_detected = faceCascade.detectMultiScale(gray, scaleFactor=1.2, minNeighbors=5, minSize=(30, 30))
        for (x, y, w, h) in faces_detected:
            cv2.rectangle(img, (x, y), (x + w, y + h), (0, 255, 0), 2)
            id, confidence = recognizer.predict(gray[y:y + h, x:x + w])
            with open('names.txt', 'r') as file:
                names_identifiers = file.readlines()
            if(confidence>70):
            	for name_identifier in names_identifiers:
                	name, identifier = name_identifier.strip().split(':')
                	if str(id) == identifier:
                    		recognized_name = name
                    		break
            	else:
                	recognized_name = "Unknown"
            else:
                	recognized_name = "Unknown"
            current_time = time.time()
            if recognized_name in last_entry_time and current_time - last_entry_time[recognized_name] < 30:
                continue
            cv2.putText(img, recognized_name, (x + 5, y - 5), font, 1, (255, 255, 255), 2)
            if recognized_name == "Unknown":
            	engine.say("Unknown person please sign in register")
            	engine.runAndWait()
            else:
            	engine.say("Welcome " + recognized_name)
            	engine.runAndWait()

            with open('entries.csv', mode='a', newline='') as file:
                writer = csv.writer(file)
                writer.writerow([recognized_name, str(datetime.datetime.now())])


            last_entry_time[recognized_name] = current_time

        cv2.imshow('Face Recognition', img)

        if cv2.waitKey(1) == ord('q'):
            break

    cam.release()
    cv2.destroyAllWindows()

root = tk.Tk()
root.title("Face Security System")


capture_button = tk.Button(root, text="Capture Images", command=capture_images)
capture_button.pack()

recognizer_button = tk.Button(root, text="Start Recognizer", command=lambda: [train_recognizer(), recognize_person()])
recognizer_button.pack()

root.mainloop()
