import numpy as np

def standard_scaler(X):
    mean = X.mean(0)
    sd = X.std(0)
    return (X - mean)/sd

def sigmoid(z):
    return (1 + np.exp(-z))**(-1)

def predict(features, weights):
    z = np.dot(features, weights)
    return sigmoid(z)

def cost_function(features, labels, weights):
    observations = len(labels)
    predictions = predict(features, weights)
    class1_cost = -labels * np.log(predictions)#1 instead of 0
    class2_cost = (1 - labels) * np.log(1 - predictions)#0 instead of 1
    cost = class1_cost - class2_cost
    cost = cost.sum() / observations
    return cost


def update_weights(features, labels, weights, lr):
    X = features
    y = labels
    N, D = X.shape
    predictions = predict(X, weights)
    gradient = np.dot(X.T, predictions - labels)
    gradient /= N
    gradient *= lr
    weights -= gradient
    return weights

def decision_boundary(prob):
    return 1 if prob >= .5 else 0

def classify(predictions):
    db = np.vectorize(decision_boundary)
    return db(predictions)

def accuracy(y_hat, y):
    acc=np.sum(y == y_hat) / len(y)
    return acc


class BinaryLR:
    def fit(self, X, y, n_iter, lr, standardize=False, has_intercept=False):
        if standardize:
            X = standard_scaler(X)
        if not has_intercept:
            ones = np.ones(X.shape[0]).reshape(-1, 1)
            X = np.concatenate((ones, X), axis=1)
        self.X = X
        self.N, self.D = X.shape
        self.y = y
        self.n_iter = n_iter
        self.lr = lr
        cost_history = []
        B = np.zeros(self.D)
        for i in range(n_iter):
            B = update_weights(self.X, self.y, B, self.lr)
            cost = cost_function(self.X, self.y, B)
            cost_history.append(cost)
            if i % 1000 == 0:
                print(" iter: " + str(i) + " cost: " + str(cost))

        self.B = B
        self.P = predict(self.X, B)
        self.yhat = classify(self.P)
        self.train_acc = accuracy(self.yhat, self.y)
        self.cost_h = cost_history

def test_score(X,y):
    #X = standard_scaler(X)
    B = classification_model.B
    ones = np.ones(X.shape[0]).reshape(-1, 1)
    X = np.concatenate((ones, X), axis = 1)
    P = predict(X, B)
    yhat=classify(P)
    return accuracy(yhat,y)

classification_model = BinaryLR()
classification_model.fit(X, y, 10**4, 0.002)